<?php
	
	// Localization domain name
	define('DIFFBLUE_L10N', 'adifferentblue');
	
	class theme_setup_different_blue{
		
		// Mainly used for saving theme options to DB
		static public $theme_prefix = 'adifferentblue_';
		
		private $themeName = "A Different Blue";
		
		private $adminPageTitle = "A Different Blue Theme Settings";
		private $adminPageShortTitle = "Theme Settings";
		
		// Prefix for options table values
		
		public function __construct() {
			
			// Setup theme options screens in WordPress admin area
			add_action("admin_menu", array($this, "setup_theme_admin_menus"));
			
			// Load theme localization textdomain
			add_action('after_setup_theme', array($this, 'localize_init'));
			
			// Add some styling to password forms in posts/pages
			add_filter('the_content', array($this, 'replace_the_password_form'));
			
			// Register the default menu
			register_nav_menu('defaultmain', __('Main navigation menu', DIFFBLUE_L10N));
			
			// Add RSS links to <head> section
			add_theme_support( 'automatic-feed-links' );
			
			add_action( 'widgets_init', array($this, 'register_sidebars') );
			
			add_theme_support( 'post-thumbnails' );
			
			add_action('wp_enqueue_scripts', array($this, 'load_scripts'));
			add_action('wp_enqueue_scripts', array($this, 'load_styles'));
			
			add_action('wp_head', array($this, 'custom_css'));

			add_filter('wp_title', array($this, 'doFilterTitle'));
		}
		
		/**
		 * Load the frontend scripts in the header 
		 */
		function load_scripts(){
			wp_register_script(DIFFBLUE_L10N.'_core', get_template_directory_uri().'/js/scripts.js', array('jquery'));
			wp_enqueue_script(DIFFBLUE_L10N.'_core');
		}
		
		/**
		 * Load the frontend styles in the header 
		 */
		function load_styles(){
			wp_register_style(DIFFBLUE_L10N.'_bootstrap', get_template_directory_uri().'/css/bootstrap.min.css');
			wp_register_style(DIFFBLUE_L10N.'_bootstrap_responsive', get_template_directory_uri().'/css/bootstrap-responsive.min.css');
			wp_register_style(DIFFBLUE_L10N.'_style', get_stylesheet_uri());
			wp_enqueue_style(array(
				DIFFBLUE_L10N.'_bootstrap',
				DIFFBLUE_L10N.'_bootstrap_responsive',
				DIFFBLUE_L10N.'_style'
			));
		}
		
		/**
		 * Display custom CSS in the header if set
		 */
		function custom_css(){
			$custom_css = stripslashes(get_option(theme_setup_different_blue::$theme_prefix . '_custom_css'));
			if($custom_css){
				echo '<style type="text/css">'.PHP_EOL;
				echo $custom_css;
				echo PHP_EOL.'</style>';
			}
		}
		
		/**
		 * Register the 3 sidebars for this theme 
		 */
		function register_sidebars(){
			// Declare sidebar widget zone
			register_sidebar(array(
				'name' => 'Sidebar Left 1',
				'id'   => 'sidebar-1',
				'description'   => 'This theme\'s layout follow this structure (left to right): Sidebar Left 1, Sidebar Left 2, Main Content and the Footer Sidebar below the other three. This is Sidebar Left 1.',
				'before_widget' => '<div class="single_widget">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="widget_heading">',
				'after_title'   => '</div>'
			));
			register_sidebar(array(
				'name' => 'Sidebar Left 2',
				'id'   => 'sidebar-2',
				'description'   => 'This theme\'s layout follow this structure (left to right): Sidebar Left 1, Sidebar Left 2, Main Content and the Footer Sidebar below the other three. This is Sidebar Left 2.',
				'before_widget' => '<div class="single_widget">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="widget_heading">',
				'after_title'   => '</div>'
			));
			register_sidebar(array(
				'name' => 'Footer Sidebar',
				'id'   => 'sidebar-footer',
				'description'   => 'This theme\'s layout follow this structure (left to right): Sidebar Left 1, Sidebar Left 2, Main Content and the Footer Sidebar below the other three. This is Footer Sidebar.',
				'before_widget' => '<div class="footer_single_widget">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="footer_widget_heading">',
				'after_title'   => '</div>'
			));
		}
		
		/**
		 * Load the textdomain to be used for this theme for localization 
		 */
		function localize_init(){
			load_theme_textdomain(DIFFBLUE_L10N, get_template_directory() . '/languages');
		}
		
		// Setup the theme's WordPress admin page
		function setup_theme_admin_menus() {
			add_theme_page(
					$this->adminPageTitle,
					$this->adminPageShortTitle,
					'manage_options',
					'different-blue-options',
					array($this, 'renderAdminPage')
				);
		}
		
		function renderAdminPage(){
			
			// Check for permissions
			if (!current_user_can('manage_options')){
				wp_die('You do not have sufficient permissions to access this page.');
				exit;
			}
			
			// Save data if the form is submitted
			if($_POST && is_array($_POST)){
				$analytics_code = esc_html($_POST[self::$theme_prefix . '_google_analytics']);
				$custom_css = esc_textarea($_POST[self::$theme_prefix . '_custom_css']);
				if($analytics_code)
					update_option(self::$theme_prefix . '_google_analytics', ($_POST[self::$theme_prefix . '_google_analytics'] ));
				if($custom_css)
					update_option(self::$theme_prefix . '_custom_css', addslashes($_POST[self::$theme_prefix . '_custom_css'] ));
			}
			?>
			<div class="wrap">
				<h2><?php echo $this->themeName ?> <?php _e('Theme Options', DIFFBLUE_L10N) ?></h2>

				<?php if($_POST): ?>
					<div id="message" class="updated"><?php _e('Settings saved', DIFFBLUE_L10N) ?></div>
				<?php endif; ?>

				<form method="POST" action="">
					<h3>
						<?php _e('General Settings', DIFFBLUE_L10N) ?>
					</h3>

					<table class="form-table">
						<tr valign="top">
							<th scope="row">
								<label for="<?php echo self::$theme_prefix; ?>_custom_css">
									<?php _e('Custom CSS', DIFFBLUE_L10N) ?>
								</label>
							</th>  
							<td>
								<textarea name="<?php echo self::$theme_prefix; ?>_custom_css" 
										placeholder="<?php _e("<style></style>", DIFFBLUE_L10N) ?>"
										class="large-text code" rows="10"><?php
									if($custom_css) echo $custom_css;
								?></textarea>
							</td>
						</tr>
					</table>

					<p class="submit">
						<input type="submit" value="<?php _e('Save changes', DIFFBLUE_L10N) ?>" class="button button-primary"/>
					</p>
				</form>  
			</div>
			<?php
		}
		
		/**
		* Apply some custom styles to the password forms inside posts/pages
		*/
		function replace_the_password_form($content) {
			global $post;
			// if there's a password and it doesn't match the cookie
			if ( !empty($post->post_password) && stripslashes($_COOKIE['wp-postpass_'.COOKIEHASH])!=$post->post_password ) {
				$output = __("This post is password protected. To view it please enter your password below:", DIFFBLUE_L10N);
				$output .= '

					<p> </p>
				<form action="'.get_option('siteurl').'/wp-pass.php" method="post" class="form-inline">

					<input name="post_password" class="input-xlarge" type="password" size="20" placeholder="Password" style="height:27px" />
					<input type="submit" name="Submit" class="btn btn-small" value="'.__("Submit", DIFFBLUE_L10N).'" />

				</form>

				';
				return $output;
			}
			else return $content;
		}

		public function doFilterTitle($title){
			$siteName = get_bloginfo('name');

			if(is_single()){
				return get_the_title(). ' | '. $siteName;
			}elseif(is_category()){
				return __("Category", DIFFBLUE_L10N).' "'.get_the_title(). '" | '. $siteName;
			}else{
				return $title;
			}
		}
	}
	
	new theme_setup_different_blue();
	
	if ( ! isset( $content_width ) ) $content_width = 900;